# terminal-ai
This is a simple CLI tool for chatting to an LLM.

Currently, only gemini is supported, but I'll add ollama support later. Nothing else is planned for now.

## How to use

Create a .env file in the same file as main.py and add the line
GEMINI_API_KEY="YOUR_KEY_HERE"

If you're on linux, run setup.py to create an alias for the command, so you can run chat <command> instead of
python main.py <command>

